/* eslint no-var: 0 */
var main = require('./dist/cjs/i18nextBrowserLanguageDetector.js');

module.exports = main;
module.exports.default = main;